from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents
import objc


class TestINFocusStatusCenter(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INFocusStatusAuthorizationStatus)

    def test_constants(self):
        self.assertEqual(Intents.INFocusStatusAuthorizationStatusNotDetermined, 0)
        self.assertEqual(Intents.INFocusStatusAuthorizationStatusRestricted, 1)
        self.assertEqual(Intents.INFocusStatusAuthorizationStatusDenied, 2)
        self.assertEqual(Intents.INFocusStatusAuthorizationStatusAuthorized, 3)

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertArgIsBlock(
            Intents.INFocusStatusCenter.requestAuthorizationWithCompletionHandler_,
            0,
            b"v" + objc._C_NSInteger,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINPersonHandleLabel(TestCase):
    def test_typed_enum(self):
        self.assertIsTypedEnum(Intents.INPersonHandleLabel, str)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertIsInstance(Intents.INPersonHandleLabelHome, str)
        self.assertIsInstance(Intents.INPersonHandleLabelWork, str)
        self.assertIsInstance(Intents.INPersonHandleLabeliPhone, str)
        self.assertIsInstance(Intents.INPersonHandleLabelMobile, str)
        self.assertIsInstance(Intents.INPersonHandleLabelMain, str)
        self.assertIsInstance(Intents.INPersonHandleLabelHomeFax, str)
        self.assertIsInstance(Intents.INPersonHandleLabelWorkFax, str)
        self.assertIsInstance(Intents.INPersonHandleLabelPager, str)
        self.assertIsInstance(Intents.INPersonHandleLabelOther, str)

    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(Intents.INPersonHandleLabelSchool, str)
